@@ -1,9 +1,8 @@
 """Tests for the Device file."""
 
-from pysmartthings.capability import (
-    Attribute,
-    Capability,
-)
+import pytest
+
+from pysmartthings.capability import Attribute, Capability
 from pysmartthings.device import (
     DEVICE_TYPE_DTH,
     DEVICE_TYPE_UNKNOWN,
@@ -12,13 +11,8 @@ from pysmartthings.device import (
     DeviceStatus,
     Status,
 )
-import pytest
 
-from .conftest import (
-    DEVICE_ID,
-    LOCATION_ID,
-    ROOM_ID,
-)
+from .conftest import DEVICE_ID, LOCATION_ID, ROOM_ID
 from .utilities import get_json
 
 
