@@ -1,11 +1,9 @@
 """Tests for the Location module."""
 
-from pysmartthings.location import (
-    Location,
-    LocationEntity,
-)
 import pytest
 
+from pysmartthings.location import Location, LocationEntity
+
 from .conftest import LOCATION_ID
 from .utilities import get_json
 
